@@ -16,7 +16,7 @@ if __name__ == '__main__':
 
 
 class Journal( Activity ):
-    """Representation of a journal unit.
+    """Representation of a journal activity.
     Not related to assignments within a Unit
     """
     title_base = "Journal"
